@@ -494,6 +494,25 @@ int eraUtctai(double utc1, double utc2, double *tai1, double *tai2);
 int eraUtcut1(double utc1, double utc2, double dut1,
               double *ut11, double *ut12);
 
+/* Astronomy/HorizonEquatorial */
+void eraAe2hd(double az, double el, double phi,
+              double *ha, double *dec);
+void eraHd2ae(double ha, double dec, double phi,
+              double *az, double *el);
+double eraHd2pa(double ha, double dec, double phi);
+
+/* Astronomy/Gnomonic */
+int eraTpors(double xi, double eta, double a, double b,
+             double *a01, double *b01, double *a02, double *b02);
+int eraTporv(double xi, double eta, double v[3],
+             double v01[3], double v02[3]);
+void eraTpsts(double xi, double eta, double a0, double b0,
+              double *a, double *b);
+void eraTpstv(double xi, double eta, double v0[3], double v[3]);
+int eraTpxes(double a, double b, double a0, double b0,
+             double *xi, double *eta);
+int eraTpxev(double v[3], double v0[3], double *xi, double *eta);
+
 /* VectorMatrix/AngleOps */
 void eraA2af(int ndp, double angle, char *sign, int idmsf[4]);
 void eraA2tf(int ndp, double angle, char *sign, int ihmsf[4]);
@@ -578,7 +597,7 @@ void eraSxpv(double s, double pv[2][3], double spv[2][3]);
 /*----------------------------------------------------------------------
 **  
 **  
-**  Copyright (C) 2013, NumFOCUS Foundation.
+**  Copyright (C) 2013-2018, NumFOCUS Foundation.
 **  All rights reserved.
 **  
 **  This library is derived, with permission, from the International
